@@ -7,6 +7,11 @@ cwd = os.getcwd()
 if not hasattr(sys, 'frozen'):
     # cx_Freeze etc. will fail here otherwise
     os.chdir(sys.exec_prefix)
+# Since Python 3.8, pywintypes needs to be imported before win32api or you get
+# ImportError: DLL load failed while importing win32api: The specified module could not be found.
+# See: https://stackoverflow.com/questions/58805040/pywin32-226-and-virtual-environments
+# Seems to be required even with pywin32 227
+import pywintypes
 import win32api
 os.chdir(cwd)
 
@@ -16,7 +21,6 @@ import numbers
 import types
 from ctypes import oledll, PyDLL, py_object, byref, POINTER, windll
 
-import pywintypes
 import pythoncom
 from win32com.client import Dispatch, CDispatch, DispatchEx
 import win32timezone
@@ -46,7 +50,7 @@ if np:
 
 N_COM_ATTEMPTS = 0      # 0 means try indefinitely
 BOOK_CALLER = None
-
+USER_CONFIG_FILE = os.path.join(os.path.expanduser("~"), '.xlwings', 'xlwings.conf')
 missing = object()
 
 
@@ -90,6 +94,9 @@ class COMRetryObjectWrapper:
     def __init__(self, inner):
         object.__setattr__(self, '_inner', inner)
 
+    def __repr__(self):
+        return repr(self._inner)
+
     def __setattr__(self, key, value):
         n_attempt = 1
         while True:
@@ -309,6 +316,10 @@ class App:
             self._xl = get_xl_app_from_hwnd(self._hwnd)
         return self._xl
 
+    @xl.setter
+    def xl(self, value):
+        self._xl = value
+
     api = xl
 
     @property
@@ -340,6 +351,7 @@ class App:
     def quit(self):
         self.xl.DisplayAlerts = False
         self.xl.Quit()
+        self.xl = None
 
     def kill(self):
         import win32api
@@ -364,6 +376,10 @@ class App:
     def display_alerts(self, value):
         self.xl.DisplayAlerts = value
 
+    @property
+    def startup_path(self):
+        return self.xl.StartupPath
+
     @property
     def calculation(self):
         return calculation_i2s[self.xl.Calculation]
@@ -412,6 +428,14 @@ class App:
     def run(self, macro, args):
         return self.xl.Run(macro, *args)
 
+    @property
+    def status_bar(self):
+        return self.xl.StatusBar
+
+    @status_bar.setter
+    def status_bar(self, value):
+        self.xl.StatusBar = value
+
 
 class Books:
 
@@ -965,6 +989,16 @@ class Range:
         else:
             return None
 
+    @property
+    def has_array(self):
+        if self.xl is not None:
+            try:
+                return self.xl.HasArray
+            except pywintypes.com_error:
+                return False
+        else:
+            return False
+
     @name.setter
     def name(self, value):
         if self.xl is not None:
